@@ -70,7 +70,7 @@ fn read_data(data_headers: DataHeaders) -> Result<Data, io::Error> {
         suggestions.push(suggestion);
 
         for (j, a) in cells.enumerate() {
-            answer_buffer[j].push(a != "");
+            answer_buffer[j].push(!a.is_empty());
             if i % 5 == 4 {
                 candidates[j].answers.push(answer_buffer[j].clone());
                 answer_buffer[j] = Vec::with_capacity(5);
@@ -102,7 +102,7 @@ fn read_data(data_headers: DataHeaders) -> Result<Data, io::Error> {
 pub fn read(path: &str, filename: &str) -> Result<Data, io::Error> {
     let f = File::open(&Path::new(path).join(format!("{}.tsv", filename))).unwrap_or_else(|_| {
         File::open(&Path::new(path).join(format!("{}.csv", filename)))
-            .expect(&format!("Fichier d'entrée manquant : {}", filename))
+            .unwrap_or_else(|_| panic!("Fichier d'entrée manquant : {}", filename))
     });
     let data_headers = read_headers(f)?;
     read_data(data_headers)
@@ -329,9 +329,9 @@ mod tests {
             Err(a) => panic!("{:?}", a),
             Ok(d) => {
                 assert_eq!(d.statuses.len(), 15);
-                assert_eq!(d.statuses[0], Status::QCM);
-                assert_eq!(d.statuses[4], Status::QRU);
-                assert_eq!(d.statuses[14], Status::QCM);
+                assert_eq!(d.statuses[0], Status::Qcm);
+                assert_eq!(d.statuses[4], Status::Qru);
+                assert_eq!(d.statuses[14], Status::Qcm);
 
                 assert_eq!(d.candidates[0].answers[0][1], true);
 
@@ -347,8 +347,8 @@ mod tests {
             Err(a) => panic!("{:?}", a),
             Ok(d) => {
                 assert_eq!(d.statuses.len(), 15);
-                assert_eq!(d.statuses[0], Status::QRU);
-                assert_eq!(d.statuses[1], Status::QCM);
+                assert_eq!(d.statuses[0], Status::Qru);
+                assert_eq!(d.statuses[1], Status::Qcm);
             }
         }
     }
