@@ -21,7 +21,7 @@ fn main() {
         std::process::exit(1);
     }
 
-    let heuristics = match read_heuristics(&Path::new(""), &Path::new("heuristiques.toml")) {
+    let heuristics = match read_heuristics(Path::new(""), Path::new("heuristiques.toml")) {
         Err(err) => {
             print_error(&err);
             std::process::exit(1)
@@ -29,8 +29,8 @@ fn main() {
         Ok(res) => res,
     };
 
-    println!("Stratégies : {:?}.\n", heuristics.strategy);
-    println!("Coeff. max : {:?}.\n", heuristics.max_coefficient);
+    println!("Annulations : {:?}.\n", heuristics.strategy);
+    println!("Coeff. max. : {:?}.\n", heuristics.max_coefficient);
 
     for file in std::env::args().skip(1) {
         if let Err(err) = process(&file, &heuristics) {
@@ -47,12 +47,12 @@ fn process(file: &str, heuristics: &Heuristics) -> Result<Vec<Vec<Axis>>> {
 
     write(&Vec::new(), &out).expect("Erreur lors de l'écriture du fichier.");
 
-    let data = read(&"data", file).unwrap_or_else(|_| panic!("Erreur d'entrée pour {}", file));
+    let data = read("data", file).unwrap_or_else(|_| panic!("Erreur d'entrée pour {}", file));
     let style = ProgressStyle::default_bar()
         .template("[{elapsed_precise}] {wide_bar} [{eta_precise}]")
         .progress_chars("░▓▒");
 
-    let axes = build_axes(&data, &heuristics);
+    let axes = build_axes(&data, heuristics);
 
     let mut partsols = vec![PartSol(Vec::new())];
 
